@@ -70,35 +70,18 @@ my_dm_total <-
   ungroup() %>%
   dm_insert_zoomed("total_loans")
 
-my_dm_total$total_loans
-
-my_dm_total %>%
+## ------------------------------------------------------------------------
+my_dm_total %>% 
+  dm_set_colors(violet = total_loans) %>% 
   dm_draw()
 
+## ------------------------------------------------------------------------
+my_dm_total$total_loans
+
+## ------------------------------------------------------------------------
 my_dm_total$total_loans %>%
   sql_render()
 
-## ------------------------------------------------------------------------
-my_dm_sqlite <- dm_financial_sqlite()
-
-my_dm_total <-
-  my_dm_sqlite %>%
-  dm_zoom_to(loans) %>%
-  group_by(account_id) %>%
-  summarize(total_amount = sum(amount, na.rm = TRUE)) %>%
-  ungroup() %>%
-  dm_insert_zoomed("total_loans")
-
-## ------------------------------------------------------------------------
-my_dm_total_computed <-
-  my_dm_total %>%
-  compute()
-
-my_dm_total_computed$total_loans
-
-my_dm_total_computed$total_loans %>%
-  sql_render()
-
 ## ------------------------------------------------------------------------
 my_dm_local <-
   my_dm_total %>%
@@ -107,43 +90,14 @@ my_dm_local <-
 my_dm_local$total_loans
 
 ## ------------------------------------------------------------------------
-my_dm_total_inplace <-
-  my_dm_sqlite %>%
-  dm_zoom_to(loans) %>%
-  group_by(account_id) %>%
-  summarize(total_amount = sum(amount, na.rm = TRUE)) %>%
-  ungroup() %>%
-  compute() %>%
-  dm_insert_zoomed("total_loans")
-
-my_dm_total_inplace$total_loans %>%
-  sql_render()
+my_dm_total %>%
+  dm_nrow()
 
 ## ------------------------------------------------------------------------
-dm_financial_sqlite
+destination_db <- DBI::dbConnect(RSQLite::SQLite())
 
-## ------------------------------------------------------------------------
-loans_df <-
-  my_dm_sqlite %>%
-  dm_squash_to_tbl(loans) %>%
-  select(id, amount, duration, A3) %>%
-  collect()
+deployed_dm <- copy_dm_to(destination_db, my_dm_local)
 
-model <- lm(amount ~ duration + A3, data = loans_df)
-
-loans_residuals <- tibble::tibble(
-  id = loans_df$id,
-  resid = unname(residuals(model))
-)
-
-my_dm_sqlite_resid <-
-  copy_to(my_dm_sqlite, loans_residuals, temporary = FALSE) %>%
-  dm_add_pk(loans_residuals, id) %>%
-  dm_add_fk(loans_residuals, id, loans)
-
-my_dm_sqlite_resid %>%
-  dm_draw()
-my_dm_sqlite_resid %>%
-  dm_examine_constraints()
-my_dm_sqlite_resid$loans_residuals
+deployed_dm
+my_dm_local
 
