@@ -5,7 +5,9 @@ if (is_this_a_test()) {
   if (rlang::is_installed("dbplyr")) {
     tbl_sum.tbl_sql <- function(x, ...) c()
     vctrs::s3_register("tibble::tbl_sum", "tbl_sql", tbl_sum.tbl_sql)
+    vctrs::s3_register("pillar::tbl_sum", "tbl_sql", tbl_sum.tbl_sql)
   }
   tbl_sum.tbl_df <- function(x, ...) c()
   vctrs::s3_register("tibble::tbl_sum", "tbl_df", tbl_sum.tbl_df)
+  vctrs::s3_register("pillar::tbl_sum", "tbl_df", tbl_sum.tbl_df)
 }
