@@ -69,7 +69,7 @@ test_that("dm_select() works for replacing fks, and removes missing ones", {
 })
 
 test_that("dm_select() removes fks if not in selection", {
-  expect_equivalent(
+  expect_equal(
     dm_select(dm_for_filter(), tf_2, c, e) %>%
       dm_get_all_fks_impl(),
     dm_get_all_fks_impl(dm_for_filter()) %>%
